/*****************************************************************************/
/* Copyright (C) 2003-2009, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/*                                                                           */
/*  This file is part of the JRS MPEG-7 Library.                             */
/*  http://mpeg-7.joanneum.at                                                */
/*                                                                           */
/*  JRS MPEG-7 Library is free software: you can redistribute it and/or      */
/*  modify it under the terms of the GNU Lesser General Public License       */
/*  (LGPL) as published by the Free Software Foundation, either version 3    */
/*  of the License, or (at your option) any later version.                   */
/*                                                                           */
/*  JRS MPEG-7 Library is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             */
/*  GNU Lesser General Public License for more details.                      */
/*                                                                           */
/*  You should have received a copy of the GNU Lesser General Public License */
/*  along with this library. If not, see <http://www.gnu.org/licenses/>.     */
/*****************************************************************************/


// ClassType_H.template
#ifndef _1309MP7JRSMEDIARELINCRTIMEPOINTTYPE_H
#define _1309MP7JRSMEDIARELINCRTIMEPOINTTYPE_H

#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsMediaRelIncrTimePointTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"


// no includefile for extension defined 
// file Mp7JrsMediaRelIncrTimePointType_ExtInclude.h


class IMp7JrsmediaDurationType;
class IMp7JrsMediaRelIncrTimePointType;
class IMp7JrsxPathRefType;
typedef Mp7JrsPtr< IMp7JrsmediaDurationType > Mp7JrsmediaDurationPtr;
typedef Mp7JrsPtr< IMp7JrsMediaRelIncrTimePointType> Mp7JrsMediaRelIncrTimePointPtr;
typedef Mp7JrsPtr< IMp7JrsxPathRefType > Mp7JrsxPathRefPtr;

/** 
 * Generated interface IMp7JrsMediaRelIncrTimePointType for class Mp7JrsMediaRelIncrTimePointType<br>
 * Located at: mpeg7-2004.xsd, line 3617<br>
 * Classified: Class<br>
 * Derived from: integer (Value)<br>
 */
class MP7JRS_EXPORT IMp7JrsMediaRelIncrTimePointType 
 :
        public Mp7JrsNode
{
public:
    // TODO: make these protected?
    IMp7JrsMediaRelIncrTimePointType();
    virtual ~IMp7JrsMediaRelIncrTimePointType();
    /**
     * Sets the content of Mp7JrsMediaRelIncrTimePointType     * @param item int
     */
    virtual void SetContent(int item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Retrieves the content of Mp7JrsMediaRelIncrTimePointType 
     * @return int
     */
    virtual int GetContent() const = 0;

    /**
     * Get mediaTimeUnit attribute.
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const = 0;

    /**
     * Get mediaTimeUnit attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeUnit() const = 0;

    /**
     * Set mediaTimeUnit attribute.
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate mediaTimeUnit attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeUnit() = 0;

    /**
     * Get mediaTimeBase attribute.
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const = 0;

    /**
     * Get mediaTimeBase attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeBase() const = 0;

    /**
     * Set mediaTimeBase attribute.
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate mediaTimeBase attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeBase() = 0;

    /**
     * Gets or creates Mp7JrsNodePtr child elements of MediaRelIncrTimePointType.
     * Currently just supports rudimentary XPath expressions as MediaRelIncrTimePointType contains no child elements of type "Mp7JrsNodePtr" at all.

     * 
     * Supported XPath expressions for GetOrCreateFromXPath
     * 
     * \par<code>/</code>
     *  - Get the root of this node.
     * \par<code>..</code>
     *  - This feature is experimental.
     *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
     * 
     *
     * @param xpath  the xpath expression to get or create.
     * @param client the ID in case of locking.
     * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
     */
    // xpath: mandatory
    // client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL) = 0;

    
// no includefile for extension defined 
// file Mp7JrsMediaRelIncrTimePointType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsMediaRelIncrTimePointType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsMediaRelIncrTimePointType<br>
 * Located at: mpeg7-2004.xsd, line 3617<br>
 * Classified: Class<br>
 * Derived from: integer (Value)<br>
 * Defined in mpeg7-2004.xsd, line 3617.<br>
 */
class MP7JRS_EXPORT Mp7JrsMediaRelIncrTimePointType :
        public IMp7JrsMediaRelIncrTimePointType
{
    friend class Mp7JrsMediaRelIncrTimePointTypeFactory; // constructs objects

public:
    /*
     * Sets the content of Mp7JrsMediaRelIncrTimePointType     * @param item int
     */
    virtual void SetContent(int item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Retrieves the content of Mp7JrsMediaRelIncrTimePointType 
     * @return int
     */
    virtual int GetContent() const;

    /*
     * Get mediaTimeUnit attribute.
     * @return Mp7JrsmediaDurationPtr
     */
    virtual Mp7JrsmediaDurationPtr GetmediaTimeUnit() const;

    /*
     * Get mediaTimeUnit attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeUnit() const;

    /*
     * Set mediaTimeUnit attribute.
     * @param item const Mp7JrsmediaDurationPtr &
     */
    virtual void SetmediaTimeUnit(const Mp7JrsmediaDurationPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate mediaTimeUnit attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeUnit();

    /*
     * Get mediaTimeBase attribute.
     * @return Mp7JrsxPathRefPtr
     */
    virtual Mp7JrsxPathRefPtr GetmediaTimeBase() const;

    /*
     * Get mediaTimeBase attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistmediaTimeBase() const;

    /*
     * Set mediaTimeBase attribute.
     * @param item const Mp7JrsxPathRefPtr &
     */
    virtual void SetmediaTimeBase(const Mp7JrsxPathRefPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate mediaTimeBase attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatemediaTimeBase();

    /*
     * Gets or creates Mp7JrsNodePtr child elements of MediaRelIncrTimePointType.
     * Currently just supports rudimentary XPath expressions as MediaRelIncrTimePointType contains no child elements of type "Mp7JrsNodePtr" at all.

     * 
     * Supported XPath expressions for GetOrCreateFromXPath
     * 
     * \par<code>/</code>
     *  - Get the root of this node.
     * \par<code>..</code>
     *  - This feature is experimental.
     *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
     * 
     *
     * @param xpath  the xpath expression to get or create.
     * @param client the ID in case of locking.
     * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
     */
    // xpath: mandatory
    // client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL);

    

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Parse the content from a string.  Note, this is purely for ComplexTypes with SimpleContent and SimpleTypes.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
	virtual bool ContentFromString(const XMLCh * const txt);

    /* Convert the content to string.  Note, this is purely for ComplexTypes with SimpleContent and SimpleTypes. All other types may return NULL or the class name.
     * @return the allocated XMLCh * if conversion was successful. The caller must free memory using Mp7JrsUtil.deallocate().
     */
	virtual XMLCh * ContentToString() const;


    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const elementname, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsMediaRelIncrTimePointType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsMediaRelIncrTimePointType();

protected:
    Mp7JrsMediaRelIncrTimePointType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7JrsmediaDurationPtr m_mediaTimeUnit;
    bool m_mediaTimeUnit_Exist;
    Mp7JrsxPathRefPtr m_mediaTimeBase;
    bool m_mediaTimeBase_Exist;

    // Base Value
    int m_Base;


// no includefile for extension defined 
// file Mp7JrsMediaRelIncrTimePointType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();
};

#endif // _1309MP7JRSMEDIARELINCRTIMEPOINTTYPE_H

