/*****************************************************************************/
/* Copyright (C) 2003-2009, JOANNEUM RESEARCH Forschungs Ges.m.b.H.          */
/* Steyrergasse 17, A-8010 Graz, Austria.                                    */
/*                                                                           */
/*  This file is part of the JRS MPEG-7 Library.                             */
/*  http://mpeg-7.joanneum.at                                                */
/*                                                                           */
/*  JRS MPEG-7 Library is free software: you can redistribute it and/or      */
/*  modify it under the terms of the GNU Lesser General Public License       */
/*  (LGPL) as published by the Free Software Foundation, either version 3    */
/*  of the License, or (at your option) any later version.                   */
/*                                                                           */
/*  JRS MPEG-7 Library is distributed in the hope that it will be useful,    */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of           */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             */
/*  GNU Lesser General Public License for more details.                      */
/*                                                                           */
/*  You should have received a copy of the GNU Lesser General Public License */
/*  along with this library. If not, see <http://www.gnu.org/licenses/>.     */
/*****************************************************************************/


// ClassType_H.template
#ifndef _1683MP7JRSPHONELEXICONTYPE_H
#define _1683MP7JRSPHONELEXICONTYPE_H

#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>

#include "Mp7JrsDefines.h"
#include "Mp7JrsFactoryDefines.h"
#include "Mp7JrsPhoneLexiconTypeFactory.h"
#include "Mp7JrsNode.h"
#include "Mp7JrsConvert.h"


// no includefile for extension defined 
// file Mp7JrsPhoneLexiconType_ExtInclude.h


#include "Mp7JrsHeaderType.h"
#include "Mp7JrsLexiconType.h"
#include "Mp7JrsMpeg7BaseType.h"
#include "Mp7JrsphoneticAlphabetType.h"
class IMp7JrsLexiconType;
class IMp7JrsPhoneLexiconType;
class IMp7JrsPhoneLexiconType_Token_CollectionType;
typedef Mp7JrsPtr< IMp7JrsLexiconType > Mp7JrsLexiconPtr;
typedef Mp7JrsPtr< IMp7JrsPhoneLexiconType_Token_CollectionType > Mp7JrsPhoneLexiconType_Token_CollectionPtr;
typedef Mp7JrsPtr< IMp7JrsPhoneLexiconType> Mp7JrsPhoneLexiconPtr;

/** 
 * Generated interface IMp7JrsPhoneLexiconType for class Mp7JrsPhoneLexiconType<br>
 * Located at: mpeg7-2004.xsd, line 2090<br>
 * Classified: Class<br>
 * Derived from: LexiconType (Class)<br>
 */
class MP7JRS_EXPORT IMp7JrsPhoneLexiconType 
 :
        public IMp7JrsLexiconType
{
public:
    // TODO: make these protected?
    IMp7JrsPhoneLexiconType();
    virtual ~IMp7JrsPhoneLexiconType();
    /**
     * Get phoneticAlphabet attribute.
     * @return Mp7JrsphoneticAlphabetType::Enumeration
     */
    virtual Mp7JrsphoneticAlphabetType::Enumeration GetphoneticAlphabet() const = 0;

    /**
     * Get phoneticAlphabet attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistphoneticAlphabet() const = 0;

    /**
     * Set phoneticAlphabet attribute.
     * @param item Mp7JrsphoneticAlphabetType::Enumeration
     */
    virtual void SetphoneticAlphabet(Mp7JrsphoneticAlphabetType::Enumeration item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate phoneticAlphabet attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatephoneticAlphabet() = 0;

        /** @name Sequence

         */
        //@{
    /**
     * Get Token element.
     * @return Mp7JrsPhoneLexiconType_Token_CollectionPtr
     */
    virtual Mp7JrsPhoneLexiconType_Token_CollectionPtr GetToken() const = 0;

    /**
     * Set Token element.
     * @param item const Mp7JrsPhoneLexiconType_Token_CollectionPtr &
     */
    // Mandatory collection
    virtual void SetToken(const Mp7JrsPhoneLexiconType_Token_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;

        //@}
    /**
     * Get numOfOriginalEntries attribute.
<br>
     * (Inherited from Mp7JrsLexiconType)
     * @return unsigned
     */
    virtual unsigned GetnumOfOriginalEntries() const = 0;

    /**
     * Get numOfOriginalEntries attribute validity information.
     * (Inherited from Mp7JrsLexiconType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistnumOfOriginalEntries() const = 0;

    /**
     * Set numOfOriginalEntries attribute.
<br>
     * (Inherited from Mp7JrsLexiconType)
     * @param item unsigned
     */
    virtual void SetnumOfOriginalEntries(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate numOfOriginalEntries attribute.
     * (Inherited from Mp7JrsLexiconType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatenumOfOriginalEntries() = 0;

    /**
     * Get id attribute.
<br>
     * (Inherited from Mp7JrsHeaderType)
     * @return XMLCh *
     */
    virtual XMLCh * Getid() const = 0;

    /**
     * Get id attribute validity information.
     * (Inherited from Mp7JrsHeaderType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existid() const = 0;

    /**
     * Set id attribute.
<br>
     * (Inherited from Mp7JrsHeaderType)
     * @param item XMLCh *
     */
    virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT) = 0;


    /**
     * Invalidate id attribute.
     * (Inherited from Mp7JrsHeaderType)
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateid() = 0;

    /**
     * Gets or creates Mp7JrsNodePtr child elements of PhoneLexiconType.
     * Currently this type contains one child element of type "Mp7JrsNodePtr".

     * <ul>
     * <li>urn:mpeg:mpeg7:schema:2004:Token</li>
     * </ul>
     * 
     * Supported XPath expressions for GetOrCreateFromXPath
     * 
     * \par<code>/</code>
     *  - Get the root of this node.
     * \par<code>..</code>
     *  - This feature is experimental.
     *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
     * 
     * \par<code>A</code> 
     * - Select all child elements named <code>A</code>.
     * - In case of no element, create a new one.
     * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
     * \par<code>A[i]</code>
     * - Select the <code>i</code>th child element of all <code>A</code>.
     * - Please note, that XPath indexes start at 1.
     * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
     * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
     * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
     * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
     * 
     * \par <code>A[\@xsi:type="T"]</code>
     *     - Select all child elements named <code>A</code> of type <code>T</code>.
     *     - Currently only typenames without namespace are recognised.
     *     - If there is no such element, create and append a new one.
     * \par <code>A[i][\@xsi:type="T"]</code>
     *     - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
     *     - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
     * \par <code>A[\@xsi:type="T"][i]</code>
     *     - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
     *     - If there is no such element at index <code>i</code>, create and append one.
     * 
     * \par <code>A[last()]</code>
     *     - Select the last child element named <code>A</code>.
     *     - In case of no element, create a new one.
     * \par <code>A[last()][\@xsi:type="T"]</code>
     *     - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
     *     - For collections: in case of no such type, create and append a new one.
     *     - For single elements: if an element with different type exists, return the empty list.
     * 
     * \par <code>A[\@xsi:type="T"][last()]</code>
     *     - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
     *     - For collections: in case of no such type, create and append a new one.
     *     - For single elements: if an element with different type exists, return the empty list.
     * 
     * \par <code>A[position() \> last()]</code>
     *     - Force creation of a child element named <code>A</code> with its default type.
     *     - For collections: create and append the default element.
     *     - For single elements: if any element exists, an exception is thrown.
     *
     * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
     *     - Force creation of a child element named <code>A</code> of type <code>T</code>.
     *     - For collections: create and append the element.
     *     - For single elements: if any element exists, an exception is thrown.
     *
     * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
     *     - Force creation of a child element named <code>A</code> of type <code>T</code>.
     *     - Behaves the same way as the previous expression.
     * 
     * 
     * Supported XPath expressions for GetFromXPath<br>
     * The same expressions like GetOrCreateFromXPath plus
     * \par <code>A[position() \< i] </code>
     *     - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
     *     - <code>i</code> must be greater than -1, otherwise an exception is thrown.
     * \par <code>A[position() \> i] </code>
     *     - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
     *     - <code>i</code> must be greater than -1, otherwise an exception is thrown.
     * \par <code>A[position() \> i | position() \< j] </code>
     *     - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
     *     - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
     *     - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
     *
     * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
     *
     * @param xpath  the xpath expression to get or create.
     * @param client the ID in case of locking.
     * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
     */
    // xpath: mandatory
    // client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL) = 0;

    
// no includefile for extension defined 
// file Mp7JrsPhoneLexiconType_ExtMethodDef.h


// no includefile for extension defined 
// file Mp7JrsPhoneLexiconType_ExtPropDef.h

};




/*
 * Generated class Mp7JrsPhoneLexiconType<br>
 * Located at: mpeg7-2004.xsd, line 2090<br>
 * Classified: Class<br>
 * Derived from: LexiconType (Class)<br>
 * Defined in mpeg7-2004.xsd, line 2090.<br>
 */
class MP7JRS_EXPORT Mp7JrsPhoneLexiconType :
        public IMp7JrsPhoneLexiconType
{
    friend class Mp7JrsPhoneLexiconTypeFactory; // constructs objects

public:
    /*
     * Retrieves the base class of Mp7JrsPhoneLexiconType
     
     * @return Mp7JrsPtr< Mp7JrsLexiconType >
     */
    virtual Mp7JrsPtr< Mp7JrsLexiconType > GetBase() const;
    /*
     * Get phoneticAlphabet attribute.
     * @return Mp7JrsphoneticAlphabetType::Enumeration
     */
    virtual Mp7JrsphoneticAlphabetType::Enumeration GetphoneticAlphabet() const;

    /*
     * Get phoneticAlphabet attribute validity information.
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistphoneticAlphabet() const;

    /*
     * Set phoneticAlphabet attribute.
     * @param item Mp7JrsphoneticAlphabetType::Enumeration
     */
    virtual void SetphoneticAlphabet(Mp7JrsphoneticAlphabetType::Enumeration item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate phoneticAlphabet attribute.
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatephoneticAlphabet();

        /* @name Sequence

         */
        //@{
    /*
     * Get Token element.
     * @return Mp7JrsPhoneLexiconType_Token_CollectionPtr
     */
    virtual Mp7JrsPhoneLexiconType_Token_CollectionPtr GetToken() const;

    /*
     * Set Token element.
     * @param item const Mp7JrsPhoneLexiconType_Token_CollectionPtr &
     */
    // Mandatory collection
    virtual void SetToken(const Mp7JrsPhoneLexiconType_Token_CollectionPtr & item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);

        //@}
    /*
     * Get numOfOriginalEntries attribute.
<br>
     * (Inherited from Mp7JrsLexiconType)
     * @return unsigned
     */
    virtual unsigned GetnumOfOriginalEntries() const;

    /*
     * Get numOfOriginalEntries attribute validity information.
     * (Inherited from Mp7JrsLexiconType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool ExistnumOfOriginalEntries() const;

    /*
     * Set numOfOriginalEntries attribute.
<br>
     * (Inherited from Mp7JrsLexiconType)
     * @param item unsigned
     */
    virtual void SetnumOfOriginalEntries(unsigned item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate numOfOriginalEntries attribute.
     * (Inherited from Mp7JrsLexiconType)
     
     * (Validate it again by setting a value)
     */
    virtual void InvalidatenumOfOriginalEntries();

    /*
     * Get id attribute.
<br>
     * (Inherited from Mp7JrsHeaderType)
     * @return XMLCh *
     */
    virtual XMLCh * Getid() const;

    /*
     * Get id attribute validity information.
     * (Inherited from Mp7JrsHeaderType)
     * @return true if attribute value is valid, false if not.
     */
    virtual bool Existid() const;

    /*
     * Set id attribute.
<br>
     * (Inherited from Mp7JrsHeaderType)
     * @param item XMLCh *
     */
    virtual void Setid(XMLCh * item, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT);


    /*
     * Invalidate id attribute.
     * (Inherited from Mp7JrsHeaderType)
     
     * (Validate it again by setting a value)
     */
    virtual void Invalidateid();

    /*
     * Gets or creates Mp7JrsNodePtr child elements of PhoneLexiconType.
     * Currently this type contains one child element of type "Mp7JrsNodePtr".

     * <ul>
     * <li>urn:mpeg:mpeg7:schema:2004:Token</li>
     * </ul>
     * 
     * Supported XPath expressions for GetOrCreateFromXPath
     * 
     * \par<code>/</code>
     *  - Get the root of this node.
     * \par<code>..</code>
     *  - This feature is experimental.
     *  - Get the ancestor (parent node), or an empty list if the node already is the root node.
     * 
     * \par<code>A</code> 
     * - Select all child elements named <code>A</code>.
     * - In case of no element, create a new one.
     * - For collections: all subsequent XPath expressions are applied on all collection items (e.g. <code>A/B</code> query or create, childnodes <code>B</code> of all <code>A</code>s). 
     * \par<code>A[i]</code>
     * - Select the <code>i</code>th child element of all <code>A</code>.
     * - Please note, that XPath indexes start at 1.
     * - If there is no such <code>i</code>th element, try to create a new one at index <code>i</code>.
     * - Single elements require <code>i</code> to be 1 otherwise an exception is thrown.
     * - For collections, <code>i</code> must not exceed the number of existing items +1 (appending is allowed, filling gaps not).
     * - If the index is too high, a <code>MissingElementException</code> is thrown, and you can extract the last valid index. (Example: If a collection contains 2 elements and you are requesting the 4th element).
     * 
     * \par <code>A[\@xsi:type="T"]</code>
     *     - Select all child elements named <code>A</code> of type <code>T</code>.
     *     - Currently only typenames without namespace are recognised.
     *     - If there is no such element, create and append a new one.
     * \par <code>A[i][\@xsi:type="T"]</code>
     *     - Select the <code>i</code>th child element named <code>A</code>, which must be of type <code>T</code>.
     *     - If there is no such element at index <code>i</code>, a new one is created and inserted (appended).
     * \par <code>A[\@xsi:type="T"][i]</code>
     *     - Out of all child elements named <code>A</code> of type <code>T</code>, take the <code>i</code>th one.
     *     - If there is no such element at index <code>i</code>, create and append one.
     * 
     * \par <code>A[last()]</code>
     *     - Select the last child element named <code>A</code>.
     *     - In case of no element, create a new one.
     * \par <code>A[last()][\@xsi:type="T"]</code>
     *     - Select the last child element named <code>A</code>, which must be of type <code>T</code>.
     *     - For collections: in case of no such type, create and append a new one.
     *     - For single elements: if an element with different type exists, return the empty list.
     * 
     * \par <code>A[\@xsi:type="T"][last()]</code>
     *     - Out of all child elements named <code>A</code> of type <code>T</code>, take the last one.
     *     - For collections: in case of no such type, create and append a new one.
     *     - For single elements: if an element with different type exists, return the empty list.
     * 
     * \par <code>A[position() \> last()]</code>
     *     - Force creation of a child element named <code>A</code> with its default type.
     *     - For collections: create and append the default element.
     *     - For single elements: if any element exists, an exception is thrown.
     *
     * \par <code>A[position() \> last()][\@xsi:type="T"]</code>
     *     - Force creation of a child element named <code>A</code> of type <code>T</code>.
     *     - For collections: create and append the element.
     *     - For single elements: if any element exists, an exception is thrown.
     *
     * \par <code>A[\@xsi:type="T"][position() \> last()]</code>
     *     - Force creation of a child element named <code>A</code> of type <code>T</code>.
     *     - Behaves the same way as the previous expression.
     * 
     * 
     * Supported XPath expressions for GetFromXPath<br>
     * The same expressions like GetOrCreateFromXPath plus
     * \par <code>A[position() \< i] </code>
     *     - Select all child elements named <code>A</code> at indexes lower than <code>i</code>.
     *     - <code>i</code> must be greater than -1, otherwise an exception is thrown.
     * \par <code>A[position() \> i] </code>
     *     - Select all child elements named <code>A</code> at indexes greater than <code>i</code>.
     *     - <code>i</code> must be greater than -1, otherwise an exception is thrown.
     * \par <code>A[position() \> i | position() \< j] </code>
     *     - Select all child elements named <code>A</code> at indexes greater than <code>i</code> and lower than <code>j</code>.
     *     - <code>i</code> and <code>j</code> must be greater than -1, otherwise an exception is thrown.
     *     - If <code>i</code> is greater than <code>j</code> then an empty list is returned.
     *
     * These three expressions can be combined with the <code>\@xsi:type</code> attribute to get a more restricted query.
     *
     * @param xpath  the xpath expression to get or create.
     * @param client the ID in case of locking.
     * @return the appropriate subelement node list. Can be empty in case of incompatible name/type/index settings.
     */
    // xpath: mandatory
    // client: optional
	virtual Mp7JrsNodeEnum GetOrCreateFromXPath(const XMLCh *xpath, Mp7JrsClientID client = MP7JRS_UNDEFINED_CLIENT, Mp7JrsXPathCreation flag = MP7JRS_FORCECREATE, Mp7JrsXPathParseContext * context = NULL);

    

    /* Get the class name.
     * @return The name of this class.
     */
    virtual XMLCh * ToText() const;

    /* Parse this type.
     * @param txt buffer to parse from.
     * @return true if parsing was successful, false otherwise.
     */
    virtual bool Parse(const XMLCh * const txt);

    /* Serialialize this object to a DOM tree.
     * @param doc DOM document.
     * @param parent Parent node in DOM tree.
     */
    virtual void Serialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement* parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement** newElem = NULL);

    /* Deserialize this object from a DOM tree.
     * @param doc DOM document.
     * @param parent Parent element in DOM tree.
     * @param current Current element in DOM tree.
     */
    virtual bool Deserialize(XERCES_CPP_NAMESPACE_QUALIFIER DOMDocument * doc, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement * parent, XERCES_CPP_NAMESPACE_QUALIFIER DOMElement ** current);

    /* Creates and inserts a Childnode of the specified Type
     * @param type The tag type of the child to be created (tag name).
     * @param xsitype The xsi type of the child to be created if available.
     * @return the created child with the correct dynamic type for the specified type.
     */
    virtual Mp7JrsNodePtr CreateChild(const XMLCh * const elementname, const XMLCh * const xsitype);
         
// no includefile for extension defined 
// file Mp7JrsPhoneLexiconType_ExtMyMethodDef.h


public:

    virtual ~Mp7JrsPhoneLexiconType();

protected:
    Mp7JrsPhoneLexiconType();
    virtual void DeepCopy(const Mp7JrsNodePtr &original);

    virtual Mp7JrsNodeEnum GetAllChildElements() const;

    virtual Mp7JrsNodePtr GetBaseRoot();
    virtual const Mp7JrsNodePtr GetBaseRoot() const;

private:
    Mp7JrsphoneticAlphabetType::Enumeration m_phoneticAlphabet;
    bool m_phoneticAlphabet_Exist;
    Mp7JrsphoneticAlphabetType::Enumeration m_phoneticAlphabet_Default;

    // Base Class
    Mp7JrsPtr< Mp7JrsLexiconType > m_Base;

    Mp7JrsPhoneLexiconType_Token_CollectionPtr m_Token;

// no includefile for extension defined 
// file Mp7JrsPhoneLexiconType_ExtMyPropDef.h


public:
    virtual void Init(); // Called by inheritees to recursively update m_myself
protected:
    void Cleanup();
};

#endif // _1683MP7JRSPHONELEXICONTYPE_H

